Structs
- Dep
- A dependency which can be automatically resolved at runtime by its unique type.
- TypeMap
- Nearly 1-to-1 with this blog:
https://nickbryan.co.uk/software/using-a-type-map-for-dependency-injection-in-rust/
A
TypeMapuniquely stores an arbitrary value by its type. No types can store more than one value.
Traits
- From
Type Map - A type which can be retrieved from a type map. Its type signature uniquely stores the type in the map.