TypeMap

Struct TypeMap 

pub struct TypeMap { /* private fields */ }
Nearly 1-to-1 with this blog: https://nickbryan.co.uk/software/using-a-type-map-for-dependency-injection-in-rust/ A TypeMap uniquely stores an arbitrary value by its type. No types can store more than one value.

Implementations

Source

impl TypeMap

pub fn new() -> Self

Creates a new, empty type map.

pub fn bind<T: Any>(&mut self, val: T) -> Option<Box<T>>

Binds the given value to its type in the type map. If an existing value for this type exists, it’s returned. An existing value with an incorrect type is returned as none.

pub fn get<T: Any>(&self) -> Option<&T>

Returns the value in this type map for this unique type.