pub trait FromTypeMap: Any + Sized {
// Required method
fn retrieve_from_map(tm: &TypeMap) -> Option<Self>;
}Expand description
A type which can be retrieved from a type map. Its type signature uniquely stores the type in the map.
Required Methods
fn retrieve_from_map(tm: &TypeMap) -> Option<Self>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.